--[[
constants.en.lua
This file defines an AceLocale table for all the various text strings needed
by AtlasLoot.  In this implementation, if a translation is missing, it will fall
back to the English translation.

The ["text"] = true; shortcut can ONLY be used for English (the root translation).
]]

--Create the library instance
local AL = AceLibrary("AceLocale-2.2"):new("AtlasLoot");

--Allow reporting of what translations are missing
AL:EnableDebugging();

--Allow the language to be changed dynamically for debugging purposes
AL:EnableDynamicLocales();

--Register translations
AL:RegisterTranslations("enUS", function() return {
    --Text strings for UI objects
    ["AtlasLoot"] = true,   --ATLASLOOT_TITLE
    ["No match found for"] = true,  --ATLASLOOT_NOMATCH
    ["Search"] = true,  --ATLASLOOT_SEARCH
    ["Clear"] = true,  --ATLASLOOT_CLEAR
    ["Select Loot Table"] = true,   --ATLASLOOT_DEFAULTFRAME_MENU
    ["Select Sub-Table"] = true,
    ["Drop Rate: "] = true,  --ATLASLOOT_DROP_RATE
    ["DKP"] = true,    --ATLASLOOT_DKP
    ["Priority:"] = true,  --ATLASLOOT_PRIORITY
    ["Click boss name to view loot."] = true,  --ATLASLOOT_BANNER_TEXT
    ["Various Locations"] = true,   --ATLASLOOT_VARIOUS_LOC
    ["This is a loot browser only.  To view maps as well, install either Atlas or Alphamap."] = true,   --ATLASLOOT_DEFAULTFRAME_NOTICE
    ["Toggle AL Panel"] = true,   --ATLASLOOT_PANEL_TOGGLE
    [" is safe."] = true,  --ATLASLOOT_SAFE_MESSAGE
    ["Server queried for "] = true,  --ATLASLOOT_QUERY_MESSAGE
    [".  Right click on any other item to refresh the loot page."] = true, --ATLASLOOT_RECLICK_MESSAGE
    ["Back"] = true,  --ATLASLOOT_UIBACK
    ["Level 60"] = true, --ATLASLOOT_LEVEL_60
    ["Level 70"] = true,  --ATLASLOOT_LEVEL_70
    ["|cffff0000(unsafe)"] = true,  --ATLASLOOT_NO_ITEMINFO
    ["Misc"] = true,  --ATLASLOOT_MISC
    ["Rewards"] = true,
    ["Heroic Mode"] = true,  --ATLASLOOT_HEROIC
    ["Normal Mode"] = true,  --ATLASLOOT_NORMAL
    ["Raid"] = true,  --ATLASLOOT_RAID 
    ["Factions - Azeroth"] = true,
    ["Factions - Outland"] = true,
    ["Factions - Shattrath City"] = true,
    ["Pre-Burning Crusade"] = true,
    ["Post-Burning Crusade"] = true,
    ["Choose Table ..."] = true,
    
    --Text for Options Panel
    ["Atlasloot Options"] = true,  --ATLASLOOT_OPTIONS_TITLE
    ["Safe Chat Links |cff1eff00(recommended)|r"] = true,  --ATLASLOOT_OPTIONS_SAFE_LINKS
    ["Enable all Chat Links |cffff0000(use at own risk)|r"] = true,  --ATLASLOOT_OPTIONS_ALL_LINKS
    ["Default Tooltips"] = true, --ATLASLOOT_OPTIONS_DEFAULT_TOOLTIPS
    ["Lootlink Tooltips"] = true, --ATLASLOOT_OPTIONS_LOOTLINK_TOOLTIPS
    ["|cff9d9d9dLootlink Tooltips|r"] = true,  --ATLASLOOT_OPTIONS_LOOTLINK_TOOLTIPS_DISABLED
    ["ItemSync Tooltips"] = true,  --ATLASLOOT_OPTIONS_ITEMSYNC_TOOLTIPS
    ["|cff9d9d9dItemSync Tooltips|r"] = true,  --ATLASLOOT_OPTIONS_ITEMSYNC_TOOLTIPS_DISABLED
    ["Use EquipCompare"] = true,  --ATLASLOOT_OPTIONS_EQUIPCOMPARE
    ["|cff9d9d9dUse EquipCompare|r"] = true,  --ATLASLOOT_OPTIONS_EQUIPCOMPARE_DISABLED
    ["Show Comparison Tooltips"] = true,
    ["Make Loot Table Opaque"] = true,  --ATLASLOOT_OPTIONS_OPAQUE
    ["Show itemIDs at all times"] = true,  --ATLASLOOT_OPTIONS_ITEMIDS
    ["Hide AtlasLoot Panel"] = true,  --ATLASLOOT_OPTIONS_HIDEPANEL
    ["Show Minimap Button"] = true,  --ATLASLOOT_OPTIONS_MINIMAP
    ["Set Minimap Button Position"] = true,  --ATLASLOOT_OPTIONS_MINIMAPPOS
    ["Suppress text spam when querying items"] = true,
    ["Done"] = true,  --ATLASLOOT_OPTIONS_DONE
    
    --Minimap Button
    ["|cff1eff00Left-Click|r Browse Loot Tables"] = true,  --ATLASLOOT_MINIMAPBUTTON_LINE1
    ["|cffff0000Right-Click|r View Options"] = true,  --ATLASLOOT_MINIMAPBUTTON_LINE2
    ["|cffff0000Shift-Click|r View Options"] = true,  --ATLASLOOT_MINIMAPBUTTON_LINE2_ALT
    ["|cffccccccLeft-Click + Drag|r Move Minimap Button"] = true,  --ATLASLOOT_MINIMAPBUTTON_LINE3
    
    --AtlasLoot Panel
    ["Options"] = true,  --ATLASLOOT_PANEL_BUTTON_OPTIONS
    ["Collections"] = true, --ATLASLOOT_PANEL_BUTTON_SETS
    ["Factions"] = true,  --ATLASLOOT_PANEL_BUTTON_REPUTATION
    
    --First time user
    ["Welcome to Atlasloot Enhanced.  Please take a moment to set your preferences for tooltips and links in the chat window.\n\n  This options screen can be reached again at any later time by typing '/atlasloot'."] = true, --ATLASLOOT_FIRST_TIME_TEXT
    ["Setup"] = true,  --ATLASLOOT_FIRST_TIME_BUTTON
    
    --Old Atlas Detected
    ["It has been detected that your version of Atlas does not match the version that Atlasloot is tuned for ("] = true, --ATLASLOOT_OLD_ATLAS_TEXT_PT1
    [").  Depending on changes, there may be the occasional error, so please visit http://www.atlasmod.com as soon as possible to update."] = true,  --ATLASLOOT_OLD_ATLAS_TEXT_PT2
    ["OK"] = true,   --ATLASLOOT_OLD_ATLAS_BUTTON
    ["Incompatible Atlas Detected"] = true,
    
    --Unsafe item tooltip
    ["Unsafe Item"] = true, --ATLASLOOT_ERRORTOOLTIP_L1
    ["ItemID:"] = true,  --ATLASLOOT_ERRORTOOLTIP_L2
    ["This item is unsafe.  To view this item without the risk of disconnection, you need to have first seen it in the game world. This is a restriction enforced by Blizzard since Patch 1.10."] = true, --ATLASLOOT_ERRORTOOLTIP_L3
    ["You can right-click to attempt to query the server.  You may be disconnected."] = true, --ATLASLOOT_ERRORTOOLTIP_L4

    --Misc Inventory related words
    ["Mount"] = true,  -- ATLASLOOT_MOUNT
    ["Enchant"] = true,  --ATLASLOOT_ENCHANT
    ["Trade Goods"] = true,  --ATLASLOOT_TRADE_GOODS
    ["Scope"] = true,  --ATLASLOOT_SCOPE
    ["Pet"] = true,  --ATLASLOOT_PET
    ["Darkmoon Faire Card"] = true,  --ATLASLOOT_DARKMOON
    ["Book"] = true,  --ATLASLOOT_BOOK
    ["Banner"] = true,  --ATLASLOOT_BANNER
    ["Set"] = true,  --ATLASLOOT_SET
    ["Token"] = true,  --ATLASLOOT_TOKEN
    ["Crafting Reagent"] = true, --ATLASLOOT_CRAFTING

    --Labels for loot descriptions
    ["Classes:"] = true,  --ATLASLOOT_CLASSES
    ["This Item Begins a Quest"] = true,  --ATLASLOOT_ITEMBEGINSQUEST
    ["Quest Item"] = true,  --ATLASLOOT_QUESTITEM
    ["Quest Reward"] = true,  --ATLASLOOT_QUESTREWARD
    ["Shared"] = true,  --ATLASLOOT_SHARED 
    ["Unique"] = true,  --ATLASLOOT_UNIQUE
    ["Right Half"] = true,  --ATLASLOOT_RIGHTSIDE
    ["Left Half"] = true,  --ATLASLOOT_LEFTSIDE
    ["28 Slot Soul Shard"] = true,  --ATLASLOOT_FELCOREBAG
    ["18 Slot"] = true,  --ATLASLOOT_ONYBAG
    ["16 Slot"] = true,  --ATLASLOOT_16SLOT
    ["10 Slot"] = true,  --ATLASLOOT_WCBAG
    ["(has random enchantment)"] = true,  --ATLASLOOT_RANDOM
    ["Use to purchase rewards"] = true, --ATLASLOOT_TOKENS, ATLASLOOT_FACTION_ARGENT_INSIGNIAS
    ["Use to purchase rewards (Horde)"] = true,  --ATLASLOOT_TOKENS_HORDE
    ["Use to purchase rewards (Alliance)"] = true,  --ATLASLOOT_TOKENS_ALLIANCE
    ["World Bosses"] = true,
    ["Reputation Factions"] = true,
    ["Sets/Collections"] = true,
    ["Card Game Item"] = true,
    
    --Special loot categories for Battlegrounds
    ["Misc. Rewards"] = true,  --ATLASLOOT_BG_MISC
    ["Superior Rewards"] = true, --ATLASLOOT_BG_BLUE
    ["Epic Rewards"] = true,  --ATLASLOOT_BG_PURPLE
    
    --Brood of Nozdormu Paths
    ["Path of the Conqueror"] = true, --ATLASLOOT_BROOD_CONQUEROR
    ["Path of the Invoker"] = true,  --ATLASLOOT_BROOD_INVOKER
    ["Path of the Protector"] = true,  --ATLASLOOT_BROOD_PROTECTOR
    
    --Violet Eye Paths
    ["Path of the Violet Protector"] = true,  --ATLASLOOT_FACTION_VIOLETEYE_PROTECTOR
    ["Path of the Violet Mage"] = true,  --ATLASLOOT_FACTION_VIOLETEYE_MAGE
    ["Path of the Violet Assassin"] = true,  --ATLASLOOT_FACTION_VIOLETEYE_ASSASSIN
    ["Path of the Violet Restorer"] = true,  --ATLASLOOT_FACTION_VIOLETEYE_RESTORER
    
    --AQ Opening Event
    ["Red Scepter Shard"] = true,  --ATLASLOOT_RED_SCEPTER
    ["Blue Scepter Shard"] = true,  --ATLASLOOT_BLUE_SCEPTER
    ["Green Scepter Shard"] = true,  --ATLASLOOT_GREEN_SCEPTER
    ["Scepter of the Shifting Sands"] = true,  --ATLASLOOT_SCEPTER
    
    --World PvP
    ["Hellfire Fortifications"] = true, 
    ["Twin Spire Ruins"] = true, --ATLASLOOT_ZONE_ZANGAR_W_PVP
    ["Spirit Towers"] = true,  --ATLASLOOT_ZONE_TEROKKAR_W_PVP
    ["Halaa"] = true,  --ATLASLOOT_ZONE_NAGRAND_W_PVP
    
    --Karazhan Opera Event Headings
    ["Shared Drops"] = true,  --ATLASLOOT_KARAOPERA_SHARED
    ["Romulo & Julianne"] = true, --ATLASLOOT_KARAOPERA_ROMEOANDJULIET
    ["Wizard of Oz"] = true,  --ATLASLOOT_KARAOPERA_WIZARDOFOZ
    ["Red Riding Hood"] = true,  --ATLASLOOT_KARAOPERA_REDRIDINGHOOD
    
    --Karazhan Animal Boss Types
    ["Spider"] = true,  --ATLASLOOT_KARA_ANIMAL_1_TYPE
    ["Darkhound"] = true,  --ATLASLOOT_KARA_ANIMAL_2_TYPE
    ["Bat"] = true,  --ATLASLOOT_KARA_ANIMAL_3_TYPE
    
    --ZG Tokens
    ["Primal Hakkari Kossack"] = true, --ATLASLOOT_Primal_Hakkari_Kossack
    ["Primal Hakkari Shawl"] = true,  --ATLASLOOT_Primal_Hakkari_Shawl
    ["Primal Hakkari Bindings"] = true, --ATLASLOOT_Primal_Hakkari_Bindings
    ["Primal Hakkari Sash"] = true, --ATLASLOOT_Primal_Hakkari_Sash
    ["Primal Hakkari Stanchion"] = true, --ATLASLOOT_Primal_Hakkari_Stanchion
    ["Primal Hakkari Aegis"] = true,  --ATLASLOOT_Primal_Hakkari_Aegis
    ["Primal Hakkari Girdle"] = true, --ATLASLOOT_Primal_Hakkari_Girdle
    ["Primal Hakkari Armsplint"] = true, --ATLASLOOT_Primal_Hakkari_Armsplint
    ["Primal Hakkari Tabard"] = true, --ATLASLOOT_Primal_Hakkari_Tabard
    
    --AQ20 Tokens
    ["Qiraji Ornate Hilt"] = true, --ATLASLOOT_Qiraji_Ornate_Hilt
    ["Qiraji Martial Drape"] = true, --ATLASLOOT_Qiraji_Martial_Drape
    ["Qiraji Magisterial Ring"] = true,  --ATLASLOOT_Qiraji_Magisterial_Ring
    ["Qiraji Ceremonial Ring"] = true,  --ATLASLOOT_Qiraji_Ceremonial_Ring
    ["Qiraji Regal Drape"] = true,   --ATLASLOOT_Qiraji_Regal_Drape
    ["Qiraji Spiked Hilt"] = true,   --ATLASLOOT_Qiraji_Spiked_Hilt
    
    --AQ40 Tokens
    ["Qiraji Bindings of Dominance"] = true, --ATLASLOOT_Qiraji_Bindings_of_Dominance
    ["Qiraji Bindings of Command"] = true, --ATLASLOOT_Qiraji_Bindings_of_Command
    ["Vek'nilash's Circlet"] = true,  --ATLASLOOT_Veknilashs_Circlet
    ["Vek'lor's Diadem"] = true,   --ATLASLOOT_Veklors_Diadem
    ["Ouro's Intact Hide"] = true,  --ATLASLOOT_Ouros_Intact_Hide
    ["Skin of the Great Sandworm"] = true,  --ATLASLOOT_Skin_of_the_Great_Sandworm
    ["Husk of the Old God"] = true,  --ATLASLOOT_Husk_of_the_Old_God
    ["Carapace of the Old God"] = true,  --ATLASLOOT_Carapace_of_the_Old_God

    --Blacksmithing Crafted Sets
    ["Imperial Plate"] = true, --ATLASLOOT_CRAFTSET_IMPERIALPLATE
    ["The Darksoul"] = true, --ATLASLOOT_CRAFTSET_DARKSOUL
    ["Fel Iron Plate"] = true, --ATLASLOOT_CRAFTSET_FELIRONPLATE
    ["Adamantite Battlegear"] = true, --ATLASLOOT_CRAFTSET_ADAMANTITEB
    ["Flame Guard"] = true, --ATLASLOOT_CRAFTSET_FLAMEGUARD
    ["Enchanted Adamantite Armor"] = true, --ATLASLOOT_CRAFTSET_ENCHANTEDADAMAN
    ["Khorium Ward"] = true, --ATLASLOOT_CRAFTSET_KHORIUM
    ["Faith in Felsteel"] = true, --ATLASLOOT_CRAFTSET_FELSTEEL
    ["Burning Rage"] = true, --ATLASLOOT_CRAFTSET_BURNINGRAGE
    ["Bloodsoul Embrace"] = true, --ATLASLOOT_CRAFTSET_BLOODSOUL
    ["Fel Iron Chain"] = true, --ATLASLOOT_CRAFTSET_FELIRONCHAIN

    --Tailoring Crafted Sets
    ["Bloodvine Garb"] = true, --ATLASLOOT_CRAFTSET_BLOODVINEGARB
    ["Netherweave Vestments"] = true, --ATLASLOOT_CRAFTSET_NEATHERVESTMENTS
    ["Imbued Netherweave"] = true, --ATLASLOOT_CRAFTSET_IMBUEDNEATHER
    ["Arcanoweave Vestments"] = true, --ATLASLOOT_CRAFTSET_ARCANOVEST
    ["The Unyielding"] = true, --ATLASLOOT_CRAFTSET_TUNYIELDING
    ["Whitemend Wisdom"] = true, --ATLASLOOT_CRAFTSET_WHITEMENDWIS
    ["Spellstrike Infusion"] = true, --ATLASLOOT_CRAFTSET_SPELLSTRIKEINFU
    ["Battlecast Garb"] = true, --ATLASLOOT_CRAFTSET_BATTLECASTG
    ["Soulcloth Embrace"] = true, --ATLASLOOT_CRAFTSET_SOULCLOTHEMBRACE
    ["Primal Mooncloth"] = true, --ATLASLOOT_CRAFTSET_PRIMALMOON
    ["Shadow's Embrace"] = true, --ATLASLOOT_CRAFTSET_SHADOWEMBRACE
    ["Wrath of Spellfire"] = true, --ATLASLOOT_CRAFTSET_WRATHSPELLFIRE

    --Leatherworking Crafted Sets
    ["Volcanic Armor"] = true, --ATLASLOOT_CRAFTSET_VOLCANICA
    ["Ironfeather Armor"] = true, --ATLASLOOT_CRAFTSET_IRONFEATHER
    ["Stormshroud Armor"] = true, --ATLASLOOT_CRAFTSET_STORMSHROUD
    ["Devilsaur Armor"] = true, --ATLASLOOT_CRAFTSET_DEVILARMOR 
    ["Blood Tiger Harness"] = true, --ATLASLOOT_CRAFTSET_BLOODTIGER 
    ["Primal Batskin"] = true, --ATLASLOOT_CRAFTSET_BATSKINA 
    ["Wild Draenish Armor"] = true, --ATLASLOOT_CRAFTSET_WILDDRAENI 
    ["Thick Draenic Armor"] = true, --ATLASLOOT_CRAFTSET_THICKDREANI 
    ["Fel Skin"] = true, --ATLASLOOT_CRAFTSET_FELSKIN 
    ["Strength of the Clefthoof"] = true, --ATLASLOOT_CRAFTSET_SCLEFTHOOF 
    ["Green Dragon Mail"] = true, --ATLASLOOT_CRAFTSET_GREENDRAGONM 
    ["Blue Dragon Mail"] = true, --ATLASLOOT_CRAFTSET_BLUEDRAGONM 
    ["Black Dragon Mail"] = true, --ATLASLOOT_CRAFTSET_BLACKDRAGONM 
    ["Scaled Draenic Armor"] = true, --ATLASLOOT_CRAFTSET_SACLEDDREANI
    ["Felscale Armor"] = true, --ATLASLOOT_CRAFTSET_FELSCALEA
    ["Felstalker Armor"] = true, --ATLASLOOT_CRAFTSET_FELSTALKERA 
    ["Fury of the Nether"] = true, --ATLASLOOT_CRAFTSET_NEATHERFURY 
    ["Primal Intent"] = true, --ATLASLOOT_CRAFTSET_PRIMALINTENT 
    ["Windhawk Armor"] = true, --ATLASLOOT_CRAFTSET_WINDHAWKA 
    ["Netherscale Armor"] = true, --ATLASLOOT_CRAFTSET_NEATHERSCALEA 
    ["Netherstrike Armor"] = true, --ATLASLOOT_CRAFTSET_NEATHERSTRIKEA 

    --Pre-60 Sets
    ["Defias Leather"] = true, --ATLASLOOT_PRE60_DEADMINES 
    ["Embrace of the Viper"] = true, --ATLASLOOT_PRE60_WAILING
    ["Chain of the Scarlet Crusade"] = true, --ATLASLOOT_PRE60_SCARLET
    ["The Gladiator"] = true, --ATLASLOOT_PRE60_BLACKROCKD
    ["Ironweave Battlesuit"] = true, --ATLASLOOT_PRE60_IRONWEAVE
    ["Necropile Raiment"] = true, --ATLASLOOT_PRE60_NECROPILE
    ["Cadaverous Garb"] = true, --ATLASLOOT_PRE60_CADAVEROUS
    ["Bloodmail Regalia"] = true, --ATLASLOOT_PRE60_BLOODMAIL
    ["Deathbone Guardian"] = true, --ATLASLOOT_PRE60_DEATHBONE
    ["The Postmaster"] = true, --ATLASLOOT_PRE60_STRAT
    ["Scourge Invasion"] = true, --ATLASLOOT_PRE60_SCOURGEINVASION
    ["Regalia of Undead Cleansing"] = true, --ATLASLOOT_PRE60_UNDEADCLOTH
    ["Undead Slayer's Armor"] = true, --ATLASLOOT_PRE60_UNDEADLEATHER
    ["Garb of the Undead Slayer"] = true, --ATLASLOOT_PRE60_UNDEADMAIL
    ["Battlegear of Undead Slaying"] = true, --ATLASLOOT_PRE60_UNDEADPLATE
    ["Shard of the Gods"] = true, --ATLASLOOT_PRE60_SHARDOFGODS
    ["Zul'Gurub Rings"] = true, --ATLASLOOT_PRE60_ZGRINGS
    ["Major Mojo Infusion"] = true, --ATLASLOOT_PRE60_MOJOINFUSION
    ["Overlord's Resolution"] = true, --ATLASLOOT_PRE60_OVERLORDRESO
    ["Prayer of the Primal"] = true, --ATLASLOOT_PRE60_PRIMALPRAYER
    ["Zanzil's Concentration"] = true, --ATLASLOOT_PRE60_ZANZILCON
    ["Spirit of Eskhandar"] = true, --ATLASLOOT_PRE60_SPIRITOFESKHANDAR
    ["The Twin Blades of Hakkari"] = true, --ATLASLOOT_PRE60_HAKKARIBLADES
    ["Primal Blessing"] = true, --ATLASLOOT_PRE60_PRIMALBLESSING
    ["Dal'Rend's Arms"] = true, --ATLASLOOT_PRE60_DALREND
    ["Spider's Kiss"] = true, --ATLASLOOT_PRE60_SPIDERKISS

    --BC Sets
    ["The Twin Stars"] = true,
    ["The Twin Blades of Azzinoth"] = true,

    --ZG Sets
    ["Haruspex's Garb"] = true, --ATLASLOOT_ZG_DRUID 
    ["Predator's Armor"] = true, --ATLASLOOT_ZG_HUNTER 
    ["Illusionist's Attire"] = true, --ATLASLOOT_ZG_MAGE 
    ["Freethinker's Armor"] = true, --ATLASLOOT_ZG_PALADIN 
    ["Confessor's Raiment"] = true, --ATLASLOOT_ZG_PRIEST 
    ["Madcap's Outfit"] = true, --ATLASLOOT_ZG_ROGUE 
    ["Augur's Regalia"] = true, --ATLASLOOT_ZG_SHAMAN 
    ["Demoniac's Threads"] = true, --ATLASLOOT_ZG_WARLOCK
    ["Vindicator's Battlegear"] = true, --ATLASLOOT_ZG_WARRIOR 

    --AQ20 Sets
    ["Symbols of Unending Life"] = true, --ATLASLOOT_AQ20_DRUID 
    ["Trappings of the Unseen Path"] = true, --ATLASLOOT_AQ20_HUNTER 
    ["Trappings of Vaulted Secrets"] = true, --ATLASLOOT_AQ20_MAGE 
    ["Battlegear of Eternal Justice"] = true, --ATLASLOOT_AQ20_PALADIN 
    ["Finery of Infinite Wisdom"] = true, --ATLASLOOT_AQ20_PRIEST 
    ["Emblems of Veiled Shadows"] = true, --ATLASLOOT_AQ20_ROGUE 
    ["Gift of the Gathering Storm"] = true, --ATLASLOOT_AQ20_SHAMAN 
    ["Implements of Unspoken Names"] = true, --ATLASLOOT_AQ20_WARLOCK 
    ["Battlegear of Unyielding Strength"] = true, --ATLASLOOT_AQ20_WARRIOR 

    --AQ40 Sets
    ["Genesis Raiment"] = true, --ATLASLOOT_AQ40_DRUID 
    ["Striker's Garb"] = true, --ATLASLOOT_AQ40_HUNTER 
    ["Enigma Vestments"] = true, --ATLASLOOT_AQ40_MAGE 
    ["Avenger's Battlegear"] = true, --ATLASLOOT_AQ40_PALADIN 
    ["Garments of the Oracle"] = true, --ATLASLOOT_AQ40_PRIEST 
    ["Deathdealer's Embrace"] = true, --ATLASLOOT_AQ40_ROGUE 
    ["Stormcaller's Garb"] = true, --ATLASLOOT_AQ40_SHAMAN 
    ["Doomcaller's Attire"] = true, --ATLASLOOT_AQ40_WARLOCK 
    ["Conqueror's Battlegear"] = true, --ATLASLOOT_AQ40_WARRIOR

    --Dungeon 1 Sets
    ["Wildheart Raiment"] = true, --ATLASLOOT_T0_DRUID 
    ["Beaststalker Armor"] = true, --ATLASLOOT_T0_HUNTER 
    ["Magister's Regalia"] = true, --ATLASLOOT_T0_MAGE 
    ["Lightforge Armor"] = true, --ATLASLOOT_T0_PALADIN 
    ["Vestments of the Devout"] = true, --ATLASLOOT_T0_PRIEST 
    ["Shadowcraft Armor"] = true, --ATLASLOOT_T0_ROGUE 
    ["The Elements"] = true, --ATLASLOOT_T0_SHAMAN 
    ["Dreadmist Raiment"] = true, --ATLASLOOT_T0_WARLOCK 
    ["Battlegear of Valor"] = true, --ATLASLOOT_T0_WARRIOR

    --Dungeon 2 Sets
    ["Feralheart Raiment"] = true, --ATLASLOOT_T05_DRUID 
    ["Beastmaster Armor"] = true, --ATLASLOOT_T05_HUNTER 
    ["Sorcerer's Regalia"] = true, --ATLASLOOT_T05_MAGE 
    ["Soulforge Armor"] = true, --ATLASLOOT_T05_PALADIN 
    ["Vestments of the Virtuous"] = true, --ATLASLOOT_T05_PRIEST 
    ["Darkmantle Armor"] = true, --ATLASLOOT_T05_ROGUE 
    ["The Five Thunders"] = true, --ATLASLOOT_T05_SHAMAN 
    ["Deathmist Raiment"] = true, --ATLASLOOT_T05_WARLOCK 
    ["Battlegear of Heroism"] = true, --ATLASLOOT_T05_WARRIOR

    --Dungeon 3 Sets
    ["Hallowed Raiment"] = true, --ATLASLOOT_DS3_HALLOWED 
    ["Incanter's Regalia"] = true, --ATLASLOOT_DS3_INCANTER 
    ["Mana-Etched Regalia"] = true, --ATLASLOOT_DS3_MANA 
    ["Oblivion Raiment"] = true, --ATLASLOOT_DS3_OBLIVION 
    ["Assassination Armor"] = true, --ATLASLOOT_DS3_ASSASSIN 
    ["Moonglade Raiment"] = true, --ATLASLOOT_DS3_MOONGLADE 
    ["Wastewalker Armor"] = true, --ATLASLOOT_DS3_WASTEWALKER 
    ["Beast Lord Armor"] = true, --ATLASLOOT_DS3_BEAST 
    ["Desolation Battlegear"] = true, --ATLASLOOT_DS3_DESOLATION
    ["Tidefury Raiment"] = true, --ATLASLOOT_DS3_TIDEFURY 
    ["Bold Armor"] = true, --ATLASLOOT_DS3_BOLD 
    ["Doomplate Battlegear"] = true, --ATLASLOOT_DS3_DOOM 
    ["Righteous Armor"] = true, --ATLASLOOT_DS3_RIGHT 

    --Tier 1 Sets
    ["Cenarion Raiment"] = true, --ATLASLOOT_T1_DRUID 
    ["Giantstalker Armor"] = true, --ATLASLOOT_T1_HUNTER 
    ["Arcanist Regalia"] = true, --ATLASLOOT_T1_MAGE 
    ["Lawbringer Armor"] = true, --ATLASLOOT_T1_PALADIN 
    ["Vestments of Prophecy"] = true, --ATLASLOOT_T1_PRIEST 
    ["Nightslayer Armor"] = true, --ATLASLOOT_T1_ROGUE 
    ["The Earthfury"] = true, --ATLASLOOT_T1_SHAMAN 
    ["Felheart Raiment"] = true, --ATLASLOOT_T1_WARLOCK 
    ["Battlegear of Might"] = true, --ATLASLOOT_T1_WARRIOR

    --Tier 2 Sets
    ["Stormrage Raiment"] = true, --ATLASLOOT_T2_DRUID 
    ["Dragonstalker Armor"] = true, --ATLASLOOT_T2_HUNTER 
    ["Netherwind Regalia"] = true, --ATLASLOOT_T2_MAGE 
    ["Judgement Armor"] = true, --ATLASLOOT_T2_PALADIN 
    ["Vestments of Transcendence"] = true, --ATLASLOOT_T2_PRIEST 
    ["Bloodfang Armor"] = true, --ATLASLOOT_T2_ROGUE 
    ["The Ten Storms"] = true, --ATLASLOOT_T2_SHAMAN 
    ["Nemesis Raiment"] = true, --ATLASLOOT_T2_WARLOCK 
    ["Battlegear of Wrath"] = true, --ATLASLOOT_T2_WARRIOR

    --Tier 3 Sets
    ["Dreamwalker Raiment"] = true, --ATLASLOOT_T3_DRUID 
    ["Cryptstalker Armor"] = true, --ATLASLOOT_T3_HUNTER 
    ["Frostfire Regalia"] = true, --ATLASLOOT_T3_MAGE 
    ["Redemption Armor"] = true, --ATLASLOOT_T3_PALADIN 
    ["Vestments of Faith"] = true, --ATLASLOOT_T3_PRIEST 
    ["Bonescythe Armor"] = true, --ATLASLOOT_T3_ROGUE 
    ["The Earthshatterer"] = true, --ATLASLOOT_T3_SHAMAN 
    ["Plagueheart Raiment"] = true, --ATLASLOOT_T3_WARLOCK 
    ["Dreadnaught's Battlegear"] = true, --ATLASLOOT_T3_WARRIOR

    --Tier 4 Sets
    ["Malorne Harness"] = true, --ATLASLOOT_T4_DRUID_1 
    ["Malorne Raiment"] = true, --ATLASLOOT_T4_DRUID_2 
    ["Malorne Regalia"] = true, --ATLASLOOT_T4_DRUID_3 
    ["Demon Stalker Armor"] = true, --ATLASLOOT_T4_HUNTER 
    ["Aldor Regalia"] = true, --ATLASLOOT_T4_MAGE 
    ["Justicar Armor"] = true, --ATLASLOOT_T4_PALADIN_1 
    ["Justicar Battlegear"] = true, --ATLASLOOT_T4_PALADIN_2 
    ["Justicar Raiment"] = true, --ATLASLOOT_T4_PALADIN_3 
    ["Incarnate Raiment"] = true, --ATLASLOOT_T4_PRIEST_1 
    ["Incarnate Regalia"] = true, --ATLASLOOT_T4_PRIEST_2 
    ["Netherblade Set"] = true, --ATLASLOOT_T4_ROGUE 
    ["Cyclone Harness"] = true, --ATLASLOOT_T4_SHAMAN_1 
    ["Cyclone Raiment"] = true, --ATLASLOOT_T4_SHAMAN_2 
    ["Cyclone Regalia"] = true, --ATLASLOOT_T4_SHAMAN_3 
    ["Voidheart Raiment"] = true, --ATLASLOOT_T4_WARLOCK 
    ["Warbringer Armor"] = true, --ATLASLOOT_T4_WARRIOR_1 
    ["Warbringer Battlegear"] = true, --ATLASLOOT_T4_WARRIOR_2 

    --Tier 5 Sets
    ["Nordrassil Harness"] = true, --ATLASLOOT_T5_DRUID_1 
    ["Nordrassil Raiment"] = true, --ATLASLOOT_T5_DRUID_2 
    ["Nordrassil Regalia"] = true, --ATLASLOOT_T5_DRUID_3 
    ["Rift Stalker Armor"] = true, --ATLASLOOT_T5_HUNTER 
    ["Tirisfal Regalia"] = true, --ATLASLOOT_T5_MAGE 
    ["Crystalforge Armor"] = true, --ATLASLOOT_T5_PALADIN_1 
    ["Crystalforge Battlegear"] = true, --ATLASLOOT_T5_PALADIN_2 
    ["Crystalforge Raiment"] = true, --ATLASLOOT_T5_PALADIN_3 
    ["Avatar Raiment"] = true, --ATLASLOOT_T5_PRIEST_1 
    ["Avatar Regalia"] = true, --ATLASLOOT_T5_PRIEST_2 
    ["Deathmantle Set"] = true, --ATLASLOOT_T5_ROGUE 
    ["Cataclysm Harness"] = true, --ATLASLOOT_T5_SHAMAN_1 
    ["Cataclysm Raiment"] = true, --ATLASLOOT_T5_SHAMAN_2 
    ["Cataclysm Regalia"] = true, --ATLASLOOT_T5_SHAMAN_3 
    ["Corruptor Raiment"] = true, --ATLASLOOT_T5_WARLOCK 
    ["Destroyer Armor"] = true, --ATLASLOOT_T5_WARRIOR_1 
    ["Destroyer Battlegear"] = true, --ATLASLOOT_T5_WARRIOR_2

    --Tier 6 Sets
    ["Thunderheart Harness"] = true, --ATLASLOOT_T6_DRUID_1 
    ["Thunderheart Raiment"] = true, --ATLASLOOT_T6_DRUID_2 
    ["Thunderheart Regalia"] = true, --ATLASLOOT_T6_DRUID_3 
    ["Gronnstalker's Armor"] = true, --ATLASLOOT_T6_HUNTER 
    ["Tempest Regalia"] = true, --ATLASLOOT_T6_MAGE 
    ["Lightbringer Armor"] = true, --ATLASLOOT_T6_PALADIN_1 
    ["Lightbringer Battlegear"] = true, --ATLASLOOT_T6_PALADIN_2 
    ["Lightbringer Raiment"] = true, --ATLASLOOT_T6_PALADIN_3 
    ["Vestments of Absolution"] = true, --ATLASLOOT_T6_PRIEST_1 
    ["Absolution Regalia"] = true, --ATLASLOOT_T6_PRIEST_2 
    ["Slayer's Armor"] = true, --ATLASLOOT_T6_ROGUE 
    ["Skyshatter Harness"] = true, --ATLASLOOT_T6_SHAMAN_1 
    ["Skyshatter Raiment"] = true, --ATLASLOOT_T6_SHAMAN_2 
    ["Skyshatter Regalia"] = true, --ATLASLOOT_T6_SHAMAN_3 
    ["Malefic Raiment"] = true, --ATLASLOOT_T6_WARLOCK 
    ["Onslaught Armor"] = true, --ATLASLOOT_T6_WARRIOR_1 
    ["Onslaught Battlegear"] = true, --ATLASLOOT_T6_WARRIOR_2

    --Arathi Basin Sets - Alliance
    ["The Highlander's Intent"] = true, --ATLASLOOT_AB_ACLOTH 
    ["The Highlander's Purpose"] = true, --ATLASLOOT_AB_ALEATHER1 
    ["The Highlander's Will"] = true, --ATLASLOOT_AB_ALEATHER2 
    ["The Highlander's Determination"] = true, --ATLASLOOT_AB_AMAIL 
    ["The Highlander's Resolve"] = true, --ATLASLOOT_AB_APLATE1 
    ["The Highlander's Resolution"] = true, --ATLASLOOT_AB_APLATE2 
    
    --Arathi Basin Sets - Horde
    ["The Defiler's Intent"] = true, --ATLASLOOT_AB_HCLOTH 
    ["The Defiler's Purpose"] = true, --ATLASLOOT_AB_HLEATHER1 
    ["The Defiler's Will"] = true, --ATLASLOOT_AB_HLEATHER2 
    ["The Defiler's Determination"] = true, --ATLASLOOT_AB_HMAIL1 
    ["The Defiler's Fortitude"] = true, --ATLASLOOT_AB_HMAIL2 
    ["The Defiler's Resolution"] = true, --ATLASLOOT_AB_HPLATE 

    --PvP Level 60 Rare Sets - Alliance
    ["Lieutenant Commander's Refuge"] = true, --ATLASLOOT_PVP_RARE_A_DRUID 
    ["Lieutenant Commander's Pursuance"] = true, --ATLASLOOT_PVP_RARE_A_HUNTER 
    ["Lieutenant Commander's Arcanum"] = true, --ATLASLOOT_PVP_RARE_A_MAGE 
    ["Lieutenant Commander's Redoubt"] = true, --ATLASLOOT_PVP_RARE_A_PALADIN 
    ["Lieutenant Commander's Investiture"] = true, --ATLASLOOT_PVP_RARE_A_PRIEST 
    ["Lieutenant Commander's Guard"] = true, --ATLASLOOT_PVP_RARE_A_ROGUE 
    ["Lieutenant Commander's Stormcaller"] = true, --ATLASLOOT_PVP_RARE_A_SHAMAN 
    ["Lieutenant Commander's Dreadgear"] = true, --ATLASLOOT_PVP_RARE_A_WARLOCK 
    ["Lieutenant Commander's Battlearmor"] = true, --ATLASLOOT_PVP_RARE_A_WARRIOR 

    --PvP Level 60 Rare Sets - Horde
    ["Champion's Refuge"] = true, --ATLASLOOT_PVP_RARE_H_DRUID 
    ["Champion's Pursuance"] = true, --ATLASLOOT_PVP_RARE_H_HUNTER 
    ["Champion's Arcanum"] = true, --ATLASLOOT_PVP_RARE_H_MAGE 
    ["Champion's Redoubt"] = true, --ATLASLOOT_PVP_RARE_H_PALADIN 
    ["Champion's Investiture"] = true, --ATLASLOOT_PVP_RARE_H_PRIEST 
    ["Champion's Guard"] = true, --ATLASLOOT_PVP_RARE_H_ROGUE 
    ["Champion's Stormcaller"] = true, --ATLASLOOT_PVP_RARE_H_SHAMAN 
    ["Champion's Dreadgear"] = true, --ATLASLOOT_PVP_RARE_H_WARLOCK 
    ["Champion's Battlearmor"] = true, --ATLASLOOT_PVP_RARE_H_WARRIOR
   
    --PvP Level 60 Epic Sets - Alliance
    ["Field Marshal's Sanctuary"] = true, --ATLASLOOT_PVP_EPIC_A_DRUID 
    ["Field Marshal's Pursuit"] = true, --ATLASLOOT_PVP_EPIC_A_HUNTER 
    ["Field Marshal's Regalia"] = true, --ATLASLOOT_PVP_EPIC_A_MAGE 
    ["Field Marshal's Aegis"] = true, --ATLASLOOT_PVP_EPIC_A_PALADIN 
    ["Field Marshal's Raiment"] = true, --ATLASLOOT_PVP_EPIC_A_PRIEST 
    ["Field Marshal's Vestments"] = true, --ATLASLOOT_PVP_EPIC_A_ROGUE 
    ["Field Marshal's Earthshaker"] = true, --ATLASLOOT_PVP_EPIC_A_SHAMAN 
    ["Field Marshal's Threads"] = true, --ATLASLOOT_PVP_EPIC_A_WARLOCK 
    ["Field Marshal's Battlegear"] = true, --ATLASLOOT_PVP_EPIC_A_WARRIOR

    --PvP Level 60 Epic Sets - Horde
    ["Warlord's Sanctuary"] = true, --ATLASLOOT_PVP_EPIC_H_DRUID 
    ["Warlord's Pursuit"] = true, --ATLASLOOT_PVP_EPIC_H_HUNTER 
    ["Warlord's Regalia"] = true, --ATLASLOOT_PVP_EPIC_H_MAGE 
    ["Warlord's Aegis"] = true, --ATLASLOOT_PVP_EPIC_H_PALADIN 
    ["Warlord's Raiment"] = true, --ATLASLOOT_PVP_EPIC_H_PRIEST 
    ["Warlord's Vestments"] = true, --ATLASLOOT_PVP_EPIC_H_ROGUE 
    ["Warlord's Earthshaker"] = true, --ATLASLOOT_PVP_EPIC_H_SHAMAN 
    ["Warlord's Threads"] = true, --ATLASLOOT_PVP_EPIC_H_WARLOCK 
    ["Warlord's Battlegear"] = true, --ATLASLOOT_PVP_EPIC_H_WARRIOR

    --PvP Level 70 Rare Sets - Alliance
    ["Grand Marshal's Sanctuary"] = true, --ATLASLOOT_PVP_70_A_DRUID_1 
    ["Grand Marshal's Wildhide"] = true, --ATLASLOOT_PVP_70_A_DRUID_2 
    ["Grand Marshal's Refuge"] = true, --ATLASLOOT_PVP_70_A_DRUID_3 
    ["Grand Marshal's Pursuit"] = true, --ATLASLOOT_PVP_70_A_HUNTER_1 
    ["Grand Marshal's Regalia"] = true, --ATLASLOOT_PVP_70_A_MAGE_1 
    ["Grand Marshal's Aegis"] = true, --ATLASLOOT_PVP_70_A_PALADIN_1 
    ["Grand Marshal's Vindication"] = true, --ATLASLOOT_PVP_70_A_PALADIN_2 
    ["Grand Marshal's Redemption"] = true, --ATLASLOOT_PVP_70_A_PALADIN_3 
    ["Grand Marshal's Raiment"] = true, --ATLASLOOT_PVP_70_A_PRIEST_1 
    ["Grand Marshal's Investiture"] = true, --ATLASLOOT_PVP_70_A_PRIEST_2 
    ["Grand Marshal's Vestments"] = true, --ATLASLOOT_PVP_70_A_ROGUE_1 
    ["Grand Marshal's Earthshaker"] = true, --ATLASLOOT_PVP_70_A_SHAMAN_1 
    ["Grand Marshal's Thunderfist"] = true, --ATLASLOOT_PVP_70_A_SHAMAN_2 
    ["Grand Marshal's Wartide"] = true, --ATLASLOOT_PVP_70_A_SHAMAN_3 
    ["Grand Marshal's Dreadgear"] = true, --ATLASLOOT_PVP_70_A_WARLOCK_1 
    ["Grand Marshal's Battlegear"] = true, --ATLASLOOT_PVP_70_A_WARRIOR_1 

    --PvP Level 70 Rare Sets - Horde
    ["High Warlord's Sanctuary"] = true, --ATLASLOOT_PVP_70_H_DRUID_1 
    ["High Warlord's Wildhide"] = true, --ATLASLOOT_PVP_70_H_DRUID_2 
    ["High Warlord's Refuge"] = true, --ATLASLOOT_PVP_70_H_DRUID_3 
    ["High Warlord's Pursuit"] = true, --ATLASLOOT_PVP_70_H_HUNTER_1 
    ["High Warlord's Regalia"] = true, --ATLASLOOT_PVP_70_H_MAGE_1 
    ["High Warlord's Aegis"] = true, --ATLASLOOT_PVP_70_H_PALADIN_1 
    ["High Warlord's Vindication"] = true, --ATLASLOOT_PVP_70_H_PALADIN_2 
    ["High Warlord's Redemption"] = true, --ATLASLOOT_PVP_70_H_PALADIN_3 
    ["High Warlord's Raiment"] = true, --ATLASLOOT_PVP_70_H_PRIEST_1 
    ["High Warlord's Investiture"] = true, --ATLASLOOT_PVP_70_H_PRIEST_2 
    ["High Warlord's Vestments"] = true, --ATLASLOOT_PVP_70_H_ROGUE_1 
    ["High Warlord's Earthshaker"] = true, --ATLASLOOT_PVP_70_H_SHAMAN_1 
    ["High Warlord's Thunderfist"] = true, --ATLASLOOT_PVP_70_H_SHAMAN_2 
    ["High Warlord's Wartide"] = true, --ATLASLOOT_PVP_70_H_SHAMAN_3 
    ["High Warlord's Dreadgear"] = true, --ATLASLOOT_PVP_70_H_WARLOCK_1 
    ["High Warlord's Battlegear"] = true, --ATLASLOOT_PVP_70_H_WARRIOR_1

    --Arena Season 1 - Epic Sets
    ["Gladiator's Sanctuary"] = true, --ATLASLOOT_ARENA_DRUID_1 
    ["Gladiator's Wildhide"] = true, --ATLASLOOT_ARENA_DRUID_2 
    ["Gladiator's Refuge"] = true, --ATLASLOOT_ARENA_DRUID_3 
    ["Gladiator's Pursuit"] = true, --ATLASLOOT_ARENA_HUNTER 
    ["Gladiator's Regalia"] = true, --ATLASLOOT_ARENA_MAGE 
    ["Gladiator's Aegis"] = true, --ATLASLOOT_ARENA_PALADIN_1 
    ["Gladiator's Vindication"] = true, --ATLASLOOT_ARENA_PALADIN_2 
    ["Gladiator's Redemption"] = true, --ATLASLOOT_ARENA_PALADIN_3 
    ["Gladiator's Raiment"] = true, --ATLASLOOT_ARENA_PRIEST_1 
    ["Gladiator's Investiture"] = true, --ATLASLOOT_ARENA_PRIEST_2 
    ["Gladiator's Vestments"] = true, --ATLASLOOT_ARENA_ROGUE 
    ["Gladiator's Earthshaker"] = true, --ATLASLOOT_ARENA_SHAMAN_1 
    ["Gladiator's Thunderfist"] = true, --ATLASLOOT_ARENA_SHAMAN_2 
    ["Gladiator's Wartide"] = true, --ATLASLOOT_ARENA_SHAMAN_3 
    ["Gladiator's Dreadgear"] = true, --ATLASLOOT_ARENA_WARLOCK_1 
    ["Gladiator's Felshroud"] = true, --ATLASLOOT_ARENA_WARLOCK_2 
    ["Gladiator's Battlegear"] = true, --ATLASLOOT_ARENA_WARRIOR 

    --Arena Season 2 - Epic Sets
    ["Merciless Gladiator's Sanctuary"] = true,
    ["Merciless Gladiator's Wildhide"] = true,
    ["Merciless Gladiator's Refuge"] = true,
    ["Merciless Gladiator's Pursuit"] = true,
    ["Merciless Gladiator's Regalia"] = true,
    ["Merciless Gladiator's Aegis"] = true,
    ["Merciless Gladiator's Vindication"] = true,
    ["Merciless Gladiator's Redemption"] = true,
    ["Merciless Gladiator's Raiment"] = true,
    ["Merciless Gladiator's Investiture"] = true,
    ["Merciless Gladiator's Vestments"] = true,
    ["Merciless Gladiator's Earthshaker"] = true,
    ["Merciless Gladiator's Thunderfist"] = true,
    ["Merciless Gladiator's Wartide"] = true,
    ["Merciless Gladiator's Dreadgear"] = true,
    ["Merciless Gladiator's Felshroud"] = true,
    ["Merciless Gladiator's Battlegear"] = true,
    
    --Set Labels
    ["Set: Embrace of the Viper"] = true,  --ATLASLOOT_VIPERSET
    ["Set: Defias Leather"] = true,   --ATLASLOOT_DEFIASSET
    ["Set: The Gladiator"] = true,  --ATLASLOOT_GLADIATORSET
    ["Set: Chain of the Scarlet Crusade"] = true,  --ATLASLOOT_SCARLETSET
    ["Set: The Postmaster"] = true,
    ["Set: Necropile Raiment"] = true,
    ["Set: Cadaverous Garb"] = true,
    ["Set: Bloodmail Regalia"] = true,
    ["Set: Deathbone Guardian"] = true,
    ["Set: Dal'Rend's Arms"] = true,
    ["Set: Spider's Kiss"] = true,
    ["Temple of Ahn'Qiraj Sets"] = true, --ATLASLOOT_AQ40_SETS
    ["AQ40 Class Sets"] = true,  --ATLASLOOT_AQ40_CLASS_SET_PIECES_1
    ["Ruins of Ahn'Qiraj Sets"] = true,  --ATLASLOOT_AQ20_SETS
    ["AQ20 Class Sets"] = true,  --ATLASLOOT_AQ20_CLASS_SET_PIECES_1
    ["AQ Enchants"] = true,  --ATLASLOOT_AQ_ENCHANTS
    ["AQ Opening Quest Chain"] = true,  --ATLASLOOT_AQ_OPENING
    ["Pre 60 Sets"] = true,  --ATLASLOOT_PRE60_SETS
    ["Crafted Sets"] = true,  --ATLASLOOT_CRAFTED_SETS
    ["Crafted Epic Weapons"] = true,
    ["Zul'Gurub Sets"] = true,  --ATLASLOOT_ZG_SETS
    ["ZG Class Sets"] = true,  --ATLASLOOT_ZG_CLASS_SET_PIECES_1
    ["ZG Enchants"] = true,  --ATLASLOOT_ZG_ENCHANTS
    ["Dungeon 1/2 Sets"] = true, --ATLASLOOT_TIER0_SETS
    ["Dungeon 1 Set"] = true,
    ["Dungeon 2 Set"] = true,  --ATLASLOOT_DS2_SET
    ["Dungeon 3 Sets"] = true,  --ATLASLOOT_DS3_SETS
    ["Tier 1 Sets"] = true,  --ATLASLOOT_TIER1_SETS
    ["Tier 2 Sets"] = true,  --ATLASLOOT_TIER2_SETS
    ["Tier 3 Sets"] = true,  --ATLASLOOT_TIER3_SETS
    ["Tier 4 Sets"] = true,  --ATLASLOOT_TIER4_SETS
    ["Tier 5 Sets"] = true,  --ATLASLOOT_TIER5_SETS
    ["Tier 6 Sets"] = true,  --ATLASLOOT_TIER6_SETS
    ["Tier 4"] = true,  --ATLASLOOT_TIER_4
    ["Tier 5"] = true,  --ATLASLOOT_TIER_5
    ["Tier 6"] = true,
    ["PvP Sets (Level 60)"] = true,
    ["PvP Sets (Level 70)"] = true,
    ["PvP Rewards (Level 60)"] = true,
    ["PvP Rewards (Level 70)"] = true,
    ["PvP Accessories (Level 60)"] = true,
    ["PvP Accessories (Level 70)"] = true,
    ["PvP Rewards"] = true,  --ATLASLOOT_PVP_SET_PIECES_HEADER
    ["PvP Armor Sets"] = true,  --ATLASLOOT_PVP_SETS, ATLASLOOT_PVP_SET_PIECES
    ["PvP Weapons"] = true,  --ATLASLOOT_PVP_WEAPONS
    ["PvP Accessories"] = true,  --ATLASLOOT_PVP_ACCESSORIES
    ["PvP Non-Set Epics"] = true,  --ATLASLOOT_PVP_NONSET
    ["Arena Reward"] = true, 
    ["Arena PvP Sets"] = true,  --ATLASLOOT_ARENA_SETS
    ["Arena 2 PvP Sets"] = true, --ATLASLOOT_ARENA2_SETS
    ["Arena PvP Weapons"] = true,  --ATLASLOOT_ARENA_WEAPONS
    ["Arena 2 PvP Weapons"] = true,  --ATLASLOOT_ARENA_WEAPONS
    ["Season 1"] = true, 
    ["Season 2"] = true, 
    ["Arathi Basin Sets"] = true,  --ATLASLOOT_FACTION_ARATHI_SETS
    ["Class Books"] = true,  --ATLASLOOT_CLASS_BOOKS
    ["Tribute Run"] = true,  --ATLASLOOT_TRIBUTE_RUN
    ["Dire Maul Books"] = true, --ATLASLOOT_DM_BOOKS
    ["Random Boss Loot"] = true,  --ATLASLOOT_RANDOM_LOOT
    ["Class Set Pieces"] = true,  --ATLASLOOT_CLASS_SET_PIECES
    ["Epic Set"] = true,  --ATLASLOOT_PVP_EPIC_SET
    ["Rare Set"] = true,  --ATLASLOOT_PVP_RARE_SET
    ["Legendary Items"] = true, --ATLASLOOT_LEGENDARIES
    ["Lvl 70 Instance Token Rewards"] = true,  --ATLASLOOT_HARDMODE
    ["Accesories and Weapons"] = true,  --ATLASLOOT_HARDMODE_SUB1
    ["Accessories"] = true,  --Hard mode tokens
    ["Armor and Weapons"] = true,  --Hard mode tokens
    ["Fire Resistance Gear"] = true,  --ATLASLOOT_HARDMODE_SUB2
    ["Arcane Resistance Gear"] = true,
    ["Nature Resistance Gear"] = true,
    ["Rare Mounts"] = true,  --ATLASLOOT_RAREMOUNTS
    ["Tabards"] = true,  --ATLASLOOT_TABARDS
    ["Token Hand-Ins"] = true,  --ATLASLOOT_FACTION_ARGENT_TOKEN
    ["Heroic Mode Keys"] = true,  --ATLASLOOT_BCKEYS_HEROIC
    ["Legendary Items for Kael'thas Fight"] = true,
    
    --NPCs missing from BabbleBoss
    ["Trash Mobs"] = true,  --ATLASLOOT_TRASH_MOBS
    ["Dungeon Set 2 Summonable"] = true,  --ATLASLOOT_DUNGEONSET2BOSS
    ["Highlord Kruul"] = true,  --ATLASLOOT_HLKruul
    ["Theldren"] = true,  --ATLASLOOT_Theldren
    ["Sothos and Jarien"] = true,  --ATLASLOOT_StratTwins
    ["Isalien"] = true, --ATLASLOOT_Isalien
    ["Mor Grayhoof"] = true, --ATLASLOOT_MorGray
    ["Kormok"] = true, --ATLASLOOT_Kormok
    ["Druid of the Fang"] = true, --ATLASLOOT_FANGDRUID
    ["Defias Strip Miner"] = true, --ATLASLOOT_DEFIASMINER
    ["Defias Overseer/Taskmaster"] = true,  --ATLASLOOT_DEFIASOVERSEER
    ["Scarlet Defender/Myrmidon"] = true,  --ATLASLOOT_SCARLETDEFENDER
    ["Scarlet Champion"] = true,  --ATLASLOOT_SCARLETCHAMPION
    ["Scarlet Centurion"] = true,  --ATLASLOOT_SCARLETCENTURION
    ["Scarlet Trainee"] = true,  --ATLASLOOT_SCARLET_TRAINEE
    ["Herod/Mograine"] = true,  --ATLASLOOT_SCARLETHEROD
    ["Scarlet Protector/Guardsman"] = true,  --ATLASLOOT_SCARLETPROTECTOR
    ["Eviscerator"] = true,  --ATLASLOOT_BRDARENA2
    ["Shadowforge Flame Keeper"] = true,  --ATLASLOOT_BRD_FLAMEKEEPER
    ["Olaf"] = true,  --ATLASLOOT_ULD_OLAF
    ["Eric 'The Swift'"] = true,  --ATLASLOOT_ULD_ERIK
    ["Shadow of Doom"] = true,  --ATLASLOOT_SINVASTION_SHADOWDOOM
    ["Bone Witch"] = true,  --ATLASLOOT_SINVASTION_BONEWITCH
    ["Lumbering Horror"] = true,  --ATLASLOOT_SINVASTION_LHORROR
    ["Shade of Akama"] = true,
    ["Essence of Souls"] = true,
    ["Illidari Council"] = true,
    ["Avatar of the Martyred"] = true,
    ["Yor"] = true,
    ["Anzu"] = true,
    ["Nexus Stalker"] = true,
    ["Auchenai Monk"] = true,
    ["Cabal Fanatic"] = true,
    ["Unchained Doombringer"] = true,
    
    --Zones
    ["World Drop"] = true,

    --Chests, etc
    ["Chest of The Seven"] = true,  --ATLASLOOT_BRDCHEST
    ["Dark Coffer"] = true,  --ATLASLOOT_BRD_COFFER
    ["The Secret Safe"] = true,  --ATLASLOOT_BRD_SAFE
    ["The Vault"] = true,  --ATLASLOOT_BRD_VAULT
    ["Ogre Tannin Basket"] = true,  --ATLASLOOT_DM_TANNIN
    ["Fengus's Chest"] = true,  --ATLASLOOT_DM_FENGUS
    ["The Prince's Chest"] = true,  --ATLASLOOT_DM_PRINCE
    ["Doan's Strongbox"] = true,  --ATLASLOOT_SCARLET_DOAN
    ["Frostwhisper's Embalming Fluid"] = true, --ATLASLOOT_SCHOLO_FROSTWHISPER
    ["Unforged Rune Covered Breastplate"] = true, --ATLASLOOT_UBRS_BREASTPLATE
    ["Malor's Strongbox"] = true,  --ATLASLOOT_STRAT_STRONGBOX
    ["Unfinished Painting"] = true,  --ATLASLOOT_STRAT_PAINTING
    ["Felvine Shard"] = true,  --ATLASLOOT_DM_FELVINE
    ["Baelog's Chest"] = true, --ATLASLOOT_ULD_BAELOG_CHEST
    ["Lorgalis Manuscript"] = true,
    ["Fathom Core"] = true,
    
} end)
